#
# spec file for package perl-IO-Pager
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           perl-IO-Pager
Version:        2.10
Release:        1.19
%define cpan_name IO-Pager
Summary:        Select a pager (possibly perl-based) & pipe it text if a TTY
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Libraries/Perl
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/J/JP/JPIERCE/%{cpan_name}-%{version}.tgz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(File::Which)
BuildRequires:  perl(Term::ReadKey)
BuildRequires:  perl(Test::More) >= 0.88
Requires:       perl(File::Which)
Requires:       perl(Term::ReadKey)
%{perl_requires}

%description
IO::Pager can be used to locate an available pager and set the _PAGER_
environment variable (see NOTES). It is also a factory for creating I/O
objects such as IO::Pager::Buffered and IO::Pager::Unbuffered.

IO::Pager subclasses are designed to programmatically decide whether or not
to pipe a filehandle's output to a program specified in _PAGER_. Subclasses
may implement only the IO handle methods desired and inherit the remainder
of those outlined below from IO::Pager. For anything else, YMMV. See the
appropriate subclass for implementation specific details.

%prep
%setup -q -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
# no parallel build, otherwise we get:
#   make -j8
#   make: *** No rule to make target 'blib/lib/IO/Pager/tp', needed by 'manifypods'.  Stop.
perl Makefile.PL INSTALLDIRS=vendor
make

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc CHANGES README TODO

%changelog
* Thu Nov  5 2020 Tina Müller <timueller+perl@suse.de>
- updated to 2.10
  see /usr/share/doc/packages/perl-IO-Pager/CHANGES
  2.10    Nov
  ::Perl Alter tp local script installation for parallel make. RT#133651
  ::Perl Add basic Windows support. RT#133663
  ::Perl Add TOPT environment variable to tp.
  ::Perl Enable scrollbar in interactive test 16.
* Wed Nov  4 2020 Tina Müller <timueller+perl@suse.de>
- updated to 2.01
  see /usr/share/doc/packages/perl-IO-Pager/CHANGES
  2.01	Nov 02 2020
  ::Perl Fixed bug that left terminal in unclean state if exit at EOF
  was enabled.
  ::Perl Fixed jump to end of file shortcut to show last line on bottom
  of screen instead of top to provide more context.
  ::Perl Made scrollbar interactive using xterm control sequences.
  ::Perl Added scroll wheel support using xterm control sequences.
* Tue Nov  3 2020 Tina Müller <tina.mueller@suse.com>
- Don't do parallel build
* Tue Nov  3 2020 Tina Müller <timueller+perl@suse.de>
- updated to 2.00
  see /usr/share/doc/packages/perl-IO-Pager/CHANGES
  2.00	Nov 01 2020
  Fix interactive tests 7 and 16 in bogus environments w/o PAGER. RT#13330
  Add tp to local script installation. RT#133651
  Add suport for visible scrollbar. RT#133652
  ::Perl Rename prompt() to status(), I18N{prompt} to I18N{minihelp},
  and I18N{status} to I18N{prompt}
  ::Perl Fix long lines in absence of Text::Wrap
  ::Perl Consolidate dialog()
  ::Perl Add ability to open file interactively
  ::Perl Prevent jumping to invalid bookmark
  ::Perl Fix tp -j
* Sun Jun 14 2020 Tina Müller <timueller+perl@suse.de>
- updated to 1.03
  see /usr/share/doc/packages/perl-IO-Pager/CHANGES
  1.03    Jun 13 2020
  Fix destruction warnings in Buffered
  Fix version number in Unbuffered
  Fix undefined warnings in unrealistically spartan environments.
  ::Perl Add ability to save buffer to file
  ::Perl Add search wrapping
  ::Perl Add navigation for multi-file viewing in tp.
  ::Perl Add flush buffer command to complement --tail.
  ::Perl Actually publish v1.02 changes for tp, they were made
  to a copy of the file not included in the distribution
  ::Perl Add experimental/incomplete grep mode; grep is lost
  on backwards scroll or dialog
  ::Perl Fix pause behavior in tp.
  ::Perl Fix folding; Text::Wrap was loaded at the wrong time.
  ::Perl Fix P, ^b and M-v, and add a bunch more command aliases.
  ::Perl Add work around for use of +OCRNL TTY mode to prevent
  status bar ghosting when using Enter to downline
  ::Perl restore Esc+x input
  ::Perl Remove unused (debugging) code.
* Mon Jun  8 2020 Tina Müller <timueller+perl@suse.de>
- updated to 1.02
  see /usr/share/doc/packages/perl-IO-Pager/CHANGES
  1.02	Sun Jun 07 2020
  Fix warning for undefined PAGER RT#132658
  Fix flipped operands for cmp_ok in test 11.
  Fix synthetic warning in test 9.
  Win32 path fixes (git pull #6)
  Remove deprecated POD content that some parsers carped about RT#131437
  ::Perl Add --tail mode to tp
  ::Perl Implement reflow for toggleable line numbering and folding.
  ::Perl Add support for bookmarks.
  ::Perl Add and document environment variable + switch processing to tp.
  ::Perl Rename visualBeep to visuaBell, but keep visualBeep as an alias.
  ::Perl Rename done() to close(), but keep done() as an alias.
  ::Perl Remove some debugging status updates.
  ::Perl More fixes for interactive test 16.
* Wed Oct  9 2019 <timueller+perl@suse.de>
- updated to 1.01
  see /usr/share/doc/packages/perl-IO-Pager/CHANGES
  1.01	Tue Oct 08 2019
  Add less.pm to MANIFEST
  Fix interactive test 16
  1.00	Mon Oct 07 2019
  Fork Term::Pager to IO::Pager::Perl, with many new features.
  NOTE: This is a breaking change from 0.43 & 0.44. What was
  IO::Pager::Perl in those versions is now IO::Pager::less i.e;
  a shim for pager-less systems to use the pure perl pager
  implementation in IO::Pager::Perl.
  Update bloody version number transclusions. RT#130643
  0.44	Mon Sep 30 2019
  Remove debugging calls mistakenly left in code. RT#130595
  Skip testing on dumb "terminal" setups. RT#130596
  Add (unexposed) code for less -J search line highlighting,
  and more form feed break to tp (IO::Pager::Perl).
  0.43	Sun Sep 29 2019
  Roll out a suboptimal but functional IO::Pager::Perl,
  fixing RT#130461 and RT#130565
* Fri Sep  6 2019 <timueller+perl@suse.de>
- updated to 0.42
  see /usr/share/doc/packages/perl-IO-Pager/CHANGES
  0.42	Thu Sep 05 2019
  Disambiguate tee open. RT#127551
  Stringify version. RT#127342
  Add bignum dependency RT#130319
  Add support for eventual Term::Pager v1.5
  Update META files.
* Thu Nov  8 2018 Dirk Stoecker <opensuse@dstoecker.de>
- updated to 0.40
  see /usr/share/doc/packages/perl-IO-Pager/CHANGES
* Sun Oct  8 2017 coolo@suse.com
- updated to 0.39
  see /usr/share/doc/packages/perl-IO-Pager/CHANGES
  0.39	Sat May 13 2017
  Rename t.pl to test.pl and alter behavior to address RT#120618
  i.e; MakeMaker's "helpfulness"; alternative is explicitly list
  all PM in module.
  More bloody RT#121450
  0.38	Tue May 11 2017
  0.37	Tue Apr 25 2017
  Fix tests for Perl 5.26 removal of . from @INC RT#121450
  (Patching for unreleased perl is a PITA)
  0.36	Mon Feb 29 2016
  Fix Use of uninitialized value at IO/Pager.pm line 98
  Remove dubgging statement.
  Add some additional reporting to interactive tests.
  Specify minimum Test::More version.
  0.35    Fri Jan 01 2016
  Update test 11 for Windows; okay in CMD, PowerShell and MSYS
  but tcsh and win-bash both fail.
  Add .travis.yml
* Thu Apr 16 2015 coolo@suse.com
- updated to 0.34
  see /usr/share/doc/packages/perl-IO-Pager/CHANGES
  0.34	Wed Feb 25 2015
  Fix version error in Makefile.
  Fix a bug in 3-arg open introduced by fix for 1-arg in 0.33.
  0.33	Wed Feb 25 2005
  Fix "Warning: unable to close filehandle $real_fh properly."
  Fixed FILEHANDLE only open().
  0.32	Tue Feb 24 2005
  Add 3-arg open support.
  Add eof() mechanism for semi-elegant signal handling.
  Update documentation.
  Undef $ENV{LESS} in interactive tests in case -E is set.
  Robustify t/11 for Win32 (RT#79950).
* Wed Jun  5 2013 coolo@suse.com
- updated to 0.31
    Add missing IO::Handle fallback for ::Unbuffered (RT#82351)
    Bogus fix for Windoze automatic line-ending failure of t/11 (RT#79950),
    improvements welcomed.
    Implement feature request #78270 to include support say
    Preserve layers of passed hilehandle on instantiation.
    Fixed tests under Win32 & cygwin, bug #75181.
    Swap IO::Pager:new and ::open, alter subclass::open to
    remove unnecessary level of subroutine calls
    Return IO::Handle objects when not connected to a TTY for
    transparent use of IO::Pager when programming OO.
    NOTE: This is broken, see ::less in TODO
* Tue Mar  6 2012 coolo@suse.com
- updated to 0.24
  * Fixed bug #74691, tests fail if CPANTS folk don't have a perl in PATH!
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Tue Oct 19 2010 coolo@novell.com
- add perl as explicit buildrequire
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Mon Aug 20 2007 mrueckert@suse.de
- initial package
